@@ -21,7 +21,7 @@ use Try::Tiny          qw( try catch );
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
 use App::YTDL::GetData qw( get_new_video_url );
-use App::YTDL::Helper  qw( sec_to_time encode_fs check_encode_stdout timestamp_to_upload_date HIDE_CURSOR SHOW_CURSOR );
+use App::YTDL::Helper  qw( sec_to_time encode_fs check_mapping_stdout timestamp_to_upload_date HIDE_CURSOR SHOW_CURSOR );
 
 END { print SHOW_CURSOR }
 
@@ -35,12 +35,12 @@ sub download_youtube {
             for my $fmt ( sort keys %{$info->{$ex}{$video_id}{file_name}} ) {
                 my $file_name = $info->{$ex}{$video_id}{file_name}{$fmt};
                 try {
-                    unlink encode_fs( $file_name ) or die check_encode_stdout( $opt, $file_name ) . " $!" if -f encode_fs( $file_name ) && $opt->{overwrite};
+                    unlink encode_fs( $file_name ) or die check_mapping_stdout( $opt, $file_name ) . " $!" if -f encode_fs( $file_name ) && $opt->{overwrite};
                     _download_video( $opt, $info, $ex, $video_id, $fmt, $nr );
                     timestamp_to_upload_date( $info, $ex, $video_id, $file_name ) if $opt->{modify_timestamp};
                 }
                 catch {
-                    say "$video_id - ", check_encode_stdout( $opt, $_ );
+                    say "$video_id - ", check_mapping_stdout( $opt, $_ );
                 };
                 $nr++;
             }
@@ -52,7 +52,6 @@ sub download_youtube {
 
 sub _download_video {
     my ( $opt, $info, $ex, $video_id, $fmt, $nr ) = @_;
-    my $video_url     = $info->{$ex}{$video_id}{video_url}{$fmt};
     my $file_name     = $info->{$ex}{$video_id}{file_name}{$fmt};
     my $file_basename = basename $file_name;
     my $ua = LWP::UserAgent->new(
@@ -63,7 +62,7 @@ sub _download_video {
     print HIDE_CURSOR;
     my $video_count = sprintf "%*s from %s", length $opt->{nr_videos}, $nr, $opt->{nr_videos};
     printf "  %s\n", '-' x length $video_count if $nr > 1;
-    printf "  %s (%s)\n", check_encode_stdout( $opt, $file_basename ), $info->{$ex}{$video_id}{duration} // '?';
+    printf "  %s (%s)\n", check_mapping_stdout( $opt, $file_basename ), $info->{$ex}{$video_id}{duration} // '?';
     local $SIG{INT} = sub {
         print cldown, "\n";
         print SHOW_CURSOR;
@@ -83,10 +82,11 @@ sub _download_video {
             $retries = ' ' x length $retries;
         }
         my $res;
+        my $video_url = $info->{$ex}{$video_id}{video_url}{$fmt};
         if ( ! $p->{size} ) {
             my $at = '';
             printf _p_fmt( $opt, "start" ), $video_count, $retries, $at;
-            open my $fh, '>:raw', encode_fs( $file_name ) or die check_encode_stdout( $opt, $file_name ) . " $!";
+            open my $fh, '>:raw', encode_fs( $file_name ) or die check_mapping_stdout( $opt, $file_name ) . " $!";
             _log_info( $opt, $info, $ex, $video_id, $fmt ) if $opt->{log_info};
             $res = $ua->get(
                 $video_url,
@@ -97,7 +97,7 @@ sub _download_video {
         elsif ( $p->{size} ) {
             my $at = sprintf "at %.2fM", $p->{size} / 1024 ** 2;
             printf _p_fmt( $opt, "start" ), $video_count, $retries, $at;
-            open my $fh, '>>:raw', encode_fs( $file_name ) or die check_encode_stdout( $opt, $file_name ) . " $!";
+            open my $fh, '>>:raw', encode_fs( $file_name ) or die check_mapping_stdout( $opt, $file_name ) . " $!";
             $res = $ua->get(
                 $video_url,
                 'Range'       => "bytes=$p->{size}-",
@@ -105,7 +105,7 @@ sub _download_video {
             );
             close $fh or die $!;
         }
-        my $ok = _status_line( $opt, $info, $ex, $video_id, $fmt, $p, $res, $video_count, $try, $retries );
+        my $ok = _status( $opt, $info, $ex, $video_id, $fmt, $p, $res, $video_count, $try, $retries );
         if ( $ok ) {
             last RETRY;
         }
@@ -121,12 +121,12 @@ sub _download_video {
 }
 
 
-sub _status_line {
+sub _status {
     my ( $opt, $info, $ex, $video_id, $fmt, $p, $res, $video_count, $try, $retries ) = @_;
-    my $file_name  = $info->{$ex}{$video_id}{file_name}{$fmt};
-    my $dl_time    = sec_to_time( int( tv_interval( [ $p->{starttime} ] ) ), 1 );
-    my $status     = $res->code;
-    my $pr_status  = 'status ' . $status;
+    my $file_name = $info->{$ex}{$video_id}{file_name}{$fmt};
+    my $dl_time   = sec_to_time( int( tv_interval( [ $p->{starttime} ] ) ), 1 );
+    my $status    = $res->code;
+    my $pr_status = 'status ' . $status;
     my ( $size, $avg_speed, $at, $incomplete ) = ( '' ) x 4;
     print up;
     print cldown;
@@ -169,18 +169,23 @@ sub _status_line {
         $size       = ' ';
         $avg_speed  = ' ';
         $at         = ' ';
-        $pr_status  = 'status ' . $status . '  Fetching new video url ...';
         $incomplete = ' ';
-        my $video_url     = $info->{$ex}{$video_id}{video_url}{$fmt};
-        my $new_video_url = get_new_video_url( $opt, $info, $ex, $video_id, $fmt );
-        if ( ! $new_video_url ) {
-            $pr_status .=  ' failed!';
-        }
-        elsif ( $new_video_url eq $video_url ) {
-            $pr_status .= $res->status_line;
+        my $webpage_url = $info->{$ex}{$video_id}{webpage_url};
+        if ( $webpage_url ) {
+            $pr_status  = 'status ' . $status . '  Fetching new video url ...';
+            my $new_video_url = get_new_video_url( $opt, $info, $ex, $webpage_url, $fmt );
+            if ( ! $new_video_url ) {
+                $pr_status .=  ' failed!';
+            }
+            elsif ( $new_video_url eq $info->{$ex}{$video_id}{video_url}{$fmt} ) {
+                $pr_status .= $res->status_line;
+            }
+            else {
+                $info->{$ex}{$video_id}{video_url}{$fmt} = $new_video_url;
+            }
         }
         else {
-            $video_url = $new_video_url;
+            $pr_status = $res->status_line;
         }
         printf _p_fmt( $opt, "status" ), $video_count, $retries, $dl_time, $size, $avg_speed, $at, $pr_status, $incomplete;
     }
