@@ -6,10 +6,10 @@ use strict;
 use 5.010000;
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( sec_to_time get_filename timestamp_to_upload_date encode_fs check_encode_stdout
+our @EXPORT_OK = qw( sec_to_time get_filename timestamp_to_upload_date encode_fs check_mapping_stdout
                     write_json read_json sanitize_for_path uni_capture uni_system HIDE_CURSOR SHOW_CURSOR );
 
-use Encode             qw( encode );
+use Encode             qw( encode FB_CROAK LEAVE_SRC );
 use Time::Local        qw( timelocal );
 use Unicode::Normalize qw( NFC );
 
@@ -47,12 +47,10 @@ sub get_filename {
 sub sanitize_for_path {
     my ( $opt, $str ) = @_;
     $str =~ s/^\s+|\s+\z//g;
-    $str =~ s/\s/_/g                         if $opt->{replace_spaces};
-    #$str =~ s/^\.+//                         if $^O eq 'Unix';
-    $str =~ s/[\0\/<>&]/-/g                  if $opt->{sanitize_filename} == 0;
-    $str =~ s/[\x{00}-\x{1F}"\/\\:*?<>|]/-/g if $opt->{sanitize_filename} == 1;
+    $str =~ s/\s/_/g            if $opt->{replace_spaces};
+    #$str =~ s/^\.+//            if $^O eq 'Unix';
+    $str =~ s{["/\\:*?<>&|]}{-}g if $opt->{sanitize_filename};
     # NTFS unsupported characters:  / \ : " * ? < > |       # 0x00-0x1F
-    #$str =~ s/[^A-Za-z0-9_-]/-/g             if $opt->{sanitize_filename} == 2;
     return $str;
 }
 
@@ -70,17 +68,18 @@ sub timestamp_to_upload_date {
 sub encode_fs {
     my ( $filename ) = @_;
     my $encoded_filename;
-    if ( eval { $encoded_filename = encode( 'locale_fs', NFC( $filename ), 1 ); 1 } ) {
+    if ( eval { $encoded_filename = encode( 'locale_fs', NFC $filename, FB_CROAK  ) } ) {
         return $encoded_filename;
     }
     return $filename;
 }
 
 
-sub check_encode_stdout {
+sub check_mapping_stdout {
     my $opt = shift;
     if ( wantarray ) {
         return @_ if $Encode::Locale::ENCODING_CONSOLE_OUT =~ /^UTF-/i;
+        return @_ if eval { map { encode( 'console_out', $_, FB_CROAK | LEAVE_SRC ) } @_; 1 };
         if ( $opt->{text_unidecode} ) {
             my @unidecoded;
             if ( eval { require Text::Unidecode; @unidecoded = Text::Unidecode::unidecode( @_ ); 1 } ) {
@@ -88,21 +87,21 @@ sub check_encode_stdout {
             }
         }
         binmode STDOUT, ':pop';
-        my @encoded_lax = map { encode( 'console_out', NFC( $_ ), sub { '*' } ) } @_;
+        my @encoded_lax = map { encode( 'console_out', NFC $_, sub { '*' } ) } @_;
         binmode STDOUT, ':encoding(console_out)';
         return @encoded_lax;
     }
     else {
-        my $string = shift;
-        return $string if $Encode::Locale::ENCODING_CONSOLE_OUT =~ /^UTF-/i;
+        return $_[0] if $Encode::Locale::ENCODING_CONSOLE_OUT =~ /^UTF-/i;
+        return $_[0] if eval { encode( 'console_out', $_[0], FB_CROAK | LEAVE_SRC ) };
         if ( $opt->{text_unidecode} ) {
             my $unidecoded;
-            if ( eval { require Text::Unidecode; $unidecoded = Text::Unidecode::unidecode( $string ); 1 } ) {
+            if ( eval { require Text::Unidecode; $unidecoded = Text::Unidecode::unidecode( $_[0] ); 1 } ) {
                 return $unidecoded;
             }
         }
         binmode STDOUT, ':pop';
-        my $encoded_lax = encode( 'console_out', NFC( $string ), sub { '*' } );
+        my $encoded_lax = encode( 'console_out', NFC $_[0], sub { '*' } );
         binmode STDOUT, ':encoding(console_out)';
         return $encoded_lax;
     }
@@ -168,7 +167,7 @@ sub sec_to_time {
 sub write_json {
     my ( $opt, $file, $h_ref ) = @_;
     my $json = JSON->new->pretty->canonical->utf8->encode( $h_ref );
-    open my $fh, '>', encode_fs( $file ) or die check_encode_stdout( $opt, $file ) . " $!";
+    open my $fh, '>', encode_fs( $file ) or die check_mapping_stdout( $opt, $file ) . " $!";
     print $fh $json;
     close $fh;
 }
@@ -177,7 +176,7 @@ sub write_json {
 sub read_json {
     my ( $opt, $file ) = @_;
     return {} if ! -f encode_fs( $file );
-    open my $fh, '<', encode_fs( $file ) or die check_encode_stdout( $opt, $file ) . " $!";
+    open my $fh, '<', encode_fs( $file ) or die check_mapping_stdout( $opt, $file ) . " $!";
     my $json = do { local $/; <$fh> };
     close $fh;
     my $h_ref = JSON->new->utf8->decode( $json ) if $json;
