@@ -19,7 +19,7 @@ use Term::Choose::Util qw( term_size );
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
-use App::YTDL::Helper        qw( get_filename check_encode_stdout encode_fs sanitize_for_path );
+use App::YTDL::Helper        qw( get_filename check_mapping_stdout encode_fs sanitize_for_path );
 use App::YTDL::History       qw( add_uploader_to_history write_uploader_history_to_file );
 use App::YTDL::InfoPrint     qw( linefolded_print_info );
 use App::YTDL::Options       qw( set_options );
@@ -63,7 +63,7 @@ sub get_download_infos {
             MENU: while ( 1 ) {
                 print "\n";
                 $opt->{up}++;
-                @$print_array = check_encode_stdout( $opt, @$print_array );
+                @$print_array = check_mapping_stdout( $opt, @$print_array );
                 print for @$print_array;
                 $opt->{up} += @$print_array;
                 print "\n";
@@ -152,7 +152,7 @@ sub get_download_infos {
             $info->{$ex}{$video_id}{video_dir} = $video_dir;
             printf "%*.*s : %s\n", $key_len, $key_len, 'video', $count;
             my $joined_fmts = sprintf " (%s)\n", join ' + ', @$fmt_list;
-            ( $joined_fmts ) = check_encode_stdout( $opt, $joined_fmts );
+            ( $joined_fmts ) = check_mapping_stdout( $opt, $joined_fmts );
             $print_array->[0] =~ s/\n\z//;
             $print_array->[0] .= $joined_fmts;
             print for @$print_array;
