@@ -15,7 +15,7 @@ use File::Spec::Functions qw( catfile catdir );
 use Term::Choose        qw( choose );
 use Try::Tiny           qw( try catch );
 
-use App::YTDL::Helper qw( get_filename timestamp_to_upload_date check_encode_stdout encode_fs uni_capture uni_system );
+use App::YTDL::Helper qw( get_filename timestamp_to_upload_date check_mapping_stdout encode_fs uni_capture uni_system );
 
 
 
@@ -46,7 +46,7 @@ sub search_and_merge {
                     }
                 }
                 catch {
-                    say "$video_id - Merge: ", check_encode_stdout( $opt, $_ );
+                    say "$video_id - Merge: ", check_mapping_stdout( $opt, $_ );
                     push @{$opt->{error_merge}}, $video_id;
                     $error = 1;
                 };
@@ -75,21 +75,21 @@ sub search_and_merge {
                 }
                 try {
                     _merge_video_with_audio( $opt, $video, $audio, $out );
-                    say ' ' .  check_encode_stdout( $opt, $out );
+                    say ' ' .  check_mapping_stdout( $opt, $out );
                     if ( $opt->{merged_in_files} == 1 ) {
                         my $dir_orig_files = catdir $video_dir, $opt->{dir_stream_files};
                         make_path encode_fs( $dir_orig_files );
-                        move encode_fs( $video ), encode_fs( $dir_orig_files ) or die check_encode_stdout( $opt, $video ) . " $!";
-                        move encode_fs( $audio ), encode_fs( $dir_orig_files ) or die check_encode_stdout( $opt, $audio ) . " $!";
+                        move encode_fs( $video ), encode_fs( $dir_orig_files ) or die check_mapping_stdout( $opt, $video ) . " $!";
+                        move encode_fs( $audio ), encode_fs( $dir_orig_files ) or die check_mapping_stdout( $opt, $audio ) . " $!";
                     }
                     elsif ( $opt->{merged_in_files} == 2 ) {
-                        unlink encode_fs( $video ) or die check_encode_stdout( $opt, $video ) . " $!";
-                        unlink encode_fs( $audio ) or die check_encode_stdout( $opt, $audio ) . " $!";
+                        unlink encode_fs( $video ) or die check_mapping_stdout( $opt, $video ) . " $!";
+                        unlink encode_fs( $audio ) or die check_mapping_stdout( $opt, $audio ) . " $!";
                     }
                     timestamp_to_upload_date( $info, $ex, $video_id, $out ) if $opt->{modify_timestamp};
                 }
                 catch {
-                    say "$video_id - Merge: ", check_encode_stdout( $opt, $_ );
+                    say "$video_id - Merge: ", check_mapping_stdout( $opt, $_ );
                     push @{$opt->{error_merge}}, $video_id;
                 };
             }
