@@ -131,7 +131,7 @@ sub _menus {
 
         group_list_menu => [
             [ '_fast_listmenu',  "- Fast list-menu"  ],
-            [ 'list_size_idx',   "- List size"       ],
+            [ 'small_list_size', "- List size"       ],
             [ 'list_sort_item',  "- Sort order"      ],
             [ 'show_view_count', "- Show view count" ],
         ],
@@ -293,8 +293,8 @@ sub set_options {
             elsif ( $choice eq "sanitize_filename" ) {
                 my $prompt = 'Sanitize filenames';
                 my $list = [
-                    'replace  / & < >',
-                    'replace  / \ : " * ? < > |',
+                    'keep all',
+                    'replace  / \ : " * ? < > | &',
                 ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
@@ -415,7 +415,7 @@ sub set_options {
                 my $prompt = 'Enable fast list-menu for';
                 _opt_choose_multi( $opt, $sub_menu, $current, $prompt );
             }
-            elsif ( $choice eq "list_size_idx" ) {
+            elsif ( $choice eq "small_list_size" ) {
                 my $prompt = 'Videos in list-menu';
                 my $list = [
                     'all',
